==> v1.0.tar.gz: codeigniter4cms/app/Views/layout.php <==
<!DOCTYPE html>
<html lang="en">


<head>
<meta charset="utf-8" />
<meta name ="author" content ="andy brookes"/>
<meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no">
<link  rel="stylesheet" type="text/css" href="<?php echo base_url('css/style.css'); ?>   " />
<title><?php echo $title ;?></title>
</head>

<body>
   <div class ="header" >
	
			<div class="logo">
			 <img    class ="img-fluid"     src = "<?php echo base_url('images/logo.png'); ?>" >
			</div>   
			<div class ="title"> <h1 id ="quikhand" >CI4 CMS</h1> </div>
			
      
    </div>
    
    <!-- end header-->
    
   <!-- start nav bar -->
   <br><br>

	
	
  <nav class="navbar navbar-light  navbar-expand-sm "    style="background-color: #f6baee;  "  >
  <a class="navbar-brand" href="#">Navbar</a>
  <button class="navbar-toggler" type="button" data-toggle="collapse" data-target="#navbarSupportedContent" aria-controls="navbarSupportedContent" aria-expanded="false" aria-label="Toggle navigation">
  <span class="navbar-toggler-icon"></span>
  </button>

  <div class="collapse navbar-collapse" id="navbarSupportedContent">
    <ul class="navbar-nav mr-auto">
     
      <li class="nav-item active">
        <a class="nav-link" href=" <?php echo base_url('/');?> ">Home <span class="sr-only">(current)</span></a>
      </li>
       
       <li class="nav-item">
        <a class="nav-link" href="<?php echo base_url('about_us');?>">About Us</a>
      </li>
           <li class="nav-item">
        <a class="nav-link " href="<?php echo base_url('displayGallery');?>">Gallery</a>
      </li>
       <li class="nav-item">
        <a class="nav-link " href="<?php echo base_url('form');?>">Contact Us</a>
      </li>
       <li class="nav-item">
        <a class="nav-link " href="<?php echo base_url('blogs');?>">Blogs</a>
      </li>
           
       
      
      
      
      
    </ul>
    
   
  </div>
</nav>
 <br><br><br>
 <!-- end navbar-->
 
 
 <!--start content-->
 
<?=$this->renderSection('extra')?>
 
<?= $this->renderSection('content') ?>
 
 
 <!-- end content -->
 
 <div class ="footer">

            <div class ="iconwrapper">
				   
				  
				   
				<div class ="icon">
				<a href="https://www.facebook.com/">	<i class="fab fa-facebook-f  " style ="color:black"></i>	</a>			  
				</div>
		
				<div class ="icon">
				
				</div>
				
				<div class ="icon">
				<a href="https://www.instagram.com/"><i class="fab fa-instagram" style = "color:purple"></i></a>		
				</div>
		 
		 <div class ="icon"><h4>&copy; 13/05/2020 to:<br> <?php echo $date ;?></h4>      </div>
 	   
</div>
		
</div><!--//end footer		-->	
	

				
				
<script src="<?php echo base_url('js/jquery-3.5.1.min.js');?>"></script>
<script src="<?php echo base_url('js/jquery-migrate-3.3.0.js');?>"></script>
 <script src ="<?php echo base_url('js/popper.js');?>"></script>
  <script src ="<?php echo base_url('js/bootstrap.bundle.js');?>"></script>	
	
	
	
	
	<script>
	$( document ).ready(function() {
$("button#2").hide();	
$("p#toggle").hide();
$( "button#1" ).click(function( event ) {
$("button#2").show();
$("button#1").hide();
$("p#toggle").show();
});

});  
		  
	</script>
	
	
	
	<script>	  
$( document ).ready(function() {
$( "button#2" ).click(function( event ) {
$("button#1").show();
$("button#2").hide();
$("p#toggle").hide();

});

});   
		  
 </script>		

<script>

$( document ).ready(function() {
	
	
$(".img-fluid#stop").on("taphold", function(event) {
   event.preventDefault();
   event.stopImmediatePropagation();
})

})

</script>
<!--
<script>
	$( document ).ready(function() {
	
	
$( ".img-fluid#stop" ).mouseover(function() {
  
  
 $(document)[0].oncontextmenu = function() { return false; }
   
  
 
 $(document).mousedown(function(e) {
        if( e.button == 2 ) {
            alert('Did you ask permission or pay for this image !');
            return false;
        } else {
            return true;
        }
    });





});


});



</script>
-->
<script>
var user = '{ "FirstName" : "John", "LastName" :"fred"}'
var jobject = JSON.parse(user);

document.getElementById("myuser").innerHTML= jobject.FirstName

</script>



</body>
</html>

==> 1.1.tar.gz: codeigniter4cms/app/Views/layout.php <==
<!DOCTYPE html>
<html lang="en">


<head>
<meta charset="utf-8" />
<meta name ="author" content ="andy brookes"/>
<meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no">
<link  rel="stylesheet" type="text/css" href="<?php echo base_url('css/style.css'); ?>   " />
<link rel="stylesheet" href="https://maxcdn.bootstrapcdn.com/font-awesome/4.5.0/css/font-awesome.min.css">


<title><?php echo $title ;?></title>
</head>

<body>
   <div class ="header" >
	
			<div class="logo">
			 <img    class ="img-fluid"     src = "<?php echo base_url('images/logo3.png'); ?>" >
			</div>   
				<div class ="title"> <h1 class  ="magnolia" >YourDomain</h1> </div>
      
    </div>
    
    <!-- end header-->
    
   <!-- start nav bar -->
   <br><br>

	
	
  <nav class="navbar navbar-light  navbar-expand-sm "    style="background-color:#e6dddd;;  "  >
  <a class="navbar-brand" href="#">Navbar</a>
  <button class="navbar-toggler" type="button" data-toggle="collapse" data-target="#navbarSupportedContent" aria-controls="navbarSupportedContent" aria-expanded="false" aria-label="Toggle navigation">
  <span class="navbar-toggler-icon"></span>
  </button>

  <div class="collapse navbar-collapse" id="navbarSupportedContent">
    <ul class="navbar-nav mr-auto">
     
      <li class="nav-item active">
        <a class="nav-link" href=" <?php echo base_url('/');?> ">Home <span class="sr-only">(current)</span></a>
      </li>
       
       <li class="nav-item">
        <a class="nav-link" href="<?php echo base_url('about_us');?>">About me</a>
      </li>
           <li class="nav-item">
        <a class="nav-link " href="<?php echo base_url('displayGallery');?>">Art Gallery</a>
      </li>
       <li class="nav-item">
        <a class="nav-link " href="<?php echo base_url('form');?>">Contact Us</a>
      </li>
       <li class="nav-item">
        <a class="nav-link " href="<?php echo base_url('blogs');?>">Blogs</a>
      </li>
           
        
         
          <li class="nav-item dropdown">
        <a class="nav-link dropdown-toggle" href="#" id="navbarDropdown" role="button" data-toggle="dropdown" aria-haspopup="true" aria-expanded="false">
          Fashion
        </a>
        <div class="dropdown-menu" aria-labelledby="navbarDropdown">
			<p>  </p>
          <!--<a class="dropdown-item" href="<?php echo base_url('productCat/FToner');?>">Toner n Cleanser </a>
          <a class="dropdown-item" href="<?php echo base_url('productCat/FExfoliate');?>">Exfoliate</a>
          <a class="dropdown-item" href="<?php echo base_url('productCat/Mask');?>">Mask</a>-->
          <a class="dropdown-item" href="<?php echo base_url('productCat/FMens');?>">Mens</a>
          <a class="dropdown-item" href="<?php echo base_url('productCat/FLadies');?>">Ladies</a>
          <a class="dropdown-item" href="<?php echo base_url('productCat/FAccessories');?>">Acessories</a>
          
      </li>
     
     
      
      
      
    </ul>
    
   
  </div>
</nav>
 <br><br><br>
 <!-- end navbar-->
 
 
 <!--start content-->
 
<?=$this->renderSection('extra')?>
 
<?= $this->renderSection('content') ?>
 
 
 <!-- end content -->
 
 <div class ="footer">

            <div class ="iconwrapper">
				   
				  
				   
				<div class ="icon">
				<a href="https://www.facebook.com/">	<i class="fab fa-facebook-f  " style ="color:black"></i>	</a>			  
				</div>
		
				<div class ="icon">
				
				</div>
				
				<div class ="icon">
				<a href="https://www.instagram.com/"><i class="fab fa-instagram" style = "color:purple"></i></a>		
				</div>
		 
		 <div class ="icon"><h4>&copy; 13/05/2020 to:<br> <?php echo $date ;?></h4>      </div>
 	   
</div>
		
</div><!--//end footer		-->	
	

				
				
<script src="<?php echo base_url('js/jquery-3.5.1.min.js');?>"></script>
<script src="<?php echo base_url('js/jquery-migrate-3.3.0.js');?>"></script>
 <script src ="<?php echo base_url('js/popper.js');?>"></script>
  <script src ="<?php echo base_url('js/bootstrap.bundle.js');?>"></script>	
	
	
	
	
	<script>
	$( window ).load(function() {
$("button#2").hide();	
$("p#toggle").hide();
$( "button#1" ).click(function( event ) {
$("button#2").show();
$("button#1").hide();
$("p#toggle").show();
});

});  
		  
	</script>
	
	
	
	<script>	  
$( document ).ready(function() {
$( "button#2" ).click(function( event ) {
$("button#1").show();
$("button#2").hide();
$("p#toggle").hide();

});

});   
		  
 </script>		

<script>

$( document ).ready(function() {
	
	
$(".img-fluid#stop").on("taphold", function(event) {
   event.preventDefault();
   event.stopImmediatePropagation();
})

})

</script>

<script>
	$( document ).ready(function() {
	
	
$( ".img-fluid#stop" ).mouseover(function() {
  
  
 $(document)[0].oncontextmenu = function() { return false; }
   
  
 
 $(document).mousedown(function(e) {
        if( e.button == 2 ) {
            alert('Did you ask permission or pay for this image !');
            return false;
        } else {
            return true;
        }
    });





});


});



</script>




</body>
</html>
